@@ -41,6 +41,7 @@ from . import csfr
 from . import diag
 from . import loggly
 from . import opbeat
+from . import preflight
 from . import prismic
 from . import sematext
 
@@ -51,5 +52,6 @@ from .csfr import CSFRPart, csfr_protect, csfr_ensure
 from .diag import DiagPart
 from .loggly import LogglyHandler, LogglyPart
 from .opbeat import OpbeatPart
+from .preflight import PreflightPart
 from .prismic import Prismic
 from .sematext import SematextHandler, SematextPart
