@@ -449,6 +449,7 @@ class Base(appier.Model):
     def _inlinify_premailer(cls, data, *args, **kwargs):
         premailer = appier.import_pip("premailer")
         keep_style_tags = kwargs.get("keep_style_tags", True)
+        strip_important = kwargs.get("strip_important", False)
         logging_level = kwargs.get(
             "logging_level",
             logging.INFO if appier.is_devel() else logging.ERROR
@@ -456,6 +457,7 @@ class Base(appier.Model):
         inliner = premailer.Premailer(
             data,
             keep_style_tags = keep_style_tags,
+            strip_important = strip_important,
             cssutils_logging_level = logging_level
         )
         return inliner.transform(data)
@@ -478,13 +480,13 @@ class Base(appier.Model):
         appier.Model.pre_create(self)
 
         if not hasattr(self, "enabled"): self.enabled = True
-        self.created = time.time()
-        self.modified = time.time()
+        self.created = int(time.time())
+        self.modified = int(time.time())
 
     def pre_update(self):
         appier.Model.pre_update(self)
 
-        self.modified = time.time()
+        self.modified = int(time.time())
         self.build_snapshot()
 
     def pre_delete(self):
@@ -656,6 +658,13 @@ class Base(appier.Model):
         self = self.reload(rules = False)
         self.touch_s()
 
+    @appier.operation(name = "Datefix", devel = True)
+    def op_datefix_s(self):
+        self = self.reload(rules = False)
+        self.created = int(self.created)
+        self.modified = int(self.modified)
+        self.save(immutables_a = False)
+
     @property
     def created_d(self):
         return datetime.datetime.fromtimestamp(self.created)
