@@ -900,9 +900,16 @@ class AdminPart(
     @appier.ensure(token = "admin", context = "admin")
     def build_index(self):
         empty = self.field("empty", True, cast = bool)
-        if empty: models.Search.delete_c()
-        for model in self._administrable(self.models_r):
-            model.build_index_g()
+        _async = self.field("async", True, cast = bool)
+
+        def builder():
+            if empty: models.Search.delete_c()
+            for model in self._administrable(self.models_r):
+                model.build_index_g()
+
+        if _async: self.owner.delay(builder)
+        else: builder()
+
         return self.redirect(
             self.url_for(
                 "admin.operations",
